@@ -1,4 +1,4 @@
-mod basic_matrix;
+pub mod basic_matrix;
 pub mod extended_matrix;
 pub mod shape;
 pub mod matrix_element_position;
